<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>CardWidget</name>
    <message>
        <location filename="../../cardwidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../cardwidget.ui" line="29"/>
        <source>Card Name</source>
        <translation>Nombre de la tarjeta</translation>
    </message>
    <message>
        <location filename="../../cardwidget.ui" line="38"/>
        <source>Profile:</source>
        <translation>Perfil:</translation>
    </message>
    <message>
        <location filename="../../cardwidget.cc" line="66"/>
        <source>pa_context_set_card_profile_by_index() failed</source>
        <translation>pa_context_set_card_profile_by_index() ha fallado</translation>
    </message>
</context>
<context>
    <name>Channel</name>
    <message>
        <location filename="../../channel.cc" line="89"/>
        <source>%1% (%2dB)</source>
        <comment>volume slider label [X% (YdB)]</comment>
        <translation>%1% (%2dB)</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="93"/>
        <source>%1%</source>
        <comment>volume slider label [X%]</comment>
        <translation>%1%</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="160"/>
        <source>&lt;small&gt;Silence&lt;/small&gt;</source>
        <translation>&lt;small&gt;Silencio&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="160"/>
        <source>&lt;small&gt;Min&lt;/small&gt;</source>
        <translation>&lt;small&gt;Mín&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="162"/>
        <source>&lt;small&gt;100% (0dB)&lt;/small&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="165"/>
        <source>&lt;small&gt;&lt;i&gt;Base&lt;/i&gt;&lt;/small&gt;</source>
        <translation>&lt;small&gt;&lt;i&gt;Base&lt;/i&gt;&lt;/small&gt;</translation>
    </message>
</context>
<context>
    <name>ChannelWidget</name>
    <message>
        <source>&lt;b&gt;left-front&lt;/b&gt;</source>
        <translation type="vanished">&lt;b&gt;frente-izquierda&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;small&gt;Silence&lt;/small&gt;</source>
        <translation type="vanished">&lt;small&gt;Silencio&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;small&gt;Min&lt;/small&gt;</source>
        <translation type="vanished">&lt;small&gt;Mín&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;small&gt;&lt;i&gt;Base&lt;/i&gt;&lt;/small&gt;</source>
        <translation type="vanished">&lt;small&gt;&lt;i&gt;Base&lt;/i&gt;&lt;/small&gt;</translation>
    </message>
</context>
<context>
    <name>DeviceWidget</name>
    <message>
        <location filename="../../devicewidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="36"/>
        <source>Device Title</source>
        <translation>Título del dispositivo</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="56"/>
        <source>Mute audio</source>
        <translation>Silenciar el sonido</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="69"/>
        <source>Lock channels together</source>
        <translation>Bloquear juntos los canales</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="85"/>
        <source>Set as fallback</source>
        <translation>Establecer como alternativa</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="103"/>
        <source>&lt;b&gt;Port:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Puerto:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="126"/>
        <source>Show advanced options</source>
        <translation>Mostrar opciones avanzadas</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="172"/>
        <source>PCM</source>
        <translation>PCM</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="182"/>
        <source>AC3</source>
        <translation>AC3</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="189"/>
        <source>EAC3</source>
        <translation>EAC3</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="196"/>
        <source>DTS</source>
        <translation>DTS</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="203"/>
        <source>MPEG</source>
        <translation>MPEG</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="210"/>
        <source>AAC</source>
        <translation>AAC</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="238"/>
        <source>&lt;b&gt;Latency offset:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Desviación de la latencia:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="245"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="40"/>
        <source>Rename device...</source>
        <translation>Renombrar el dispositivo...</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="154"/>
        <source>pa_context_set_port_latency_offset() failed</source>
        <translation>pa_context_set_port_latency_offset() ha fallado</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="225"/>
        <source>Sorry, but device renaming is not supported.</source>
        <translation>Lo sentimos, no es posible renombrar el dispositivo.</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="226"/>
        <source>You need to load module-device-manager in the PulseAudio server in order to rename devices</source>
        <translation>Necesita cargar module-device-manager en el servidor de PulseAudio para poder renombrar dispositivos</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="232"/>
        <source>Rename device %1 to:</source>
        <translation>Renombrar el dispositivo %1 a:</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="239"/>
        <source>pa_ext_device_manager_set_device_description() failed</source>
        <translation>pa_ext_device_manager_set_device_description() ha fallado</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Volume Control</source>
        <translation>Control de volumen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="28"/>
        <source>&amp;Playback</source>
        <translation>&amp;Reproducción</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&lt;i&gt;No application is currently playing audio.&lt;/i&gt;</source>
        <translation>&lt;i&gt;Ninguna aplicación está actualmente reproduciendo sonidos.&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="66"/>
        <location filename="../../mainwindow.ui" line="131"/>
        <location filename="../../mainwindow.ui" line="196"/>
        <location filename="../../mainwindow.ui" line="261"/>
        <source>Show:</source>
        <translation>Mostrar:</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="74"/>
        <location filename="../../mainwindow.ui" line="139"/>
        <source>All Streams</source>
        <translation>Todos los flujos</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="79"/>
        <location filename="../../mainwindow.ui" line="144"/>
        <source>Applications</source>
        <translation>Aplicaciones</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="84"/>
        <location filename="../../mainwindow.ui" line="149"/>
        <source>Virtual Streams</source>
        <translation>Flujos virtuales</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="93"/>
        <source>&amp;Recording</source>
        <translation>&amp;Grabación</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="120"/>
        <source>&lt;i&gt;No application is currently recording audio.&lt;/i&gt;</source>
        <translation>&lt;i&gt;Ninguna aplicación está actualmente grabando audio.&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="158"/>
        <source>&amp;Output Devices</source>
        <translation>Dispositivos de &amp;salida</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>&lt;i&gt;No output devices available&lt;/i&gt;</source>
        <translation>&lt;i&gt;No hay dispositivos de salida disponibles&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="204"/>
        <source>All Output Devices</source>
        <translation>Todos los dispositivos de salida</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="209"/>
        <source>Hardware Output Devices</source>
        <translation>Dispositivos de salida por hardware</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="214"/>
        <source>Virtual Output Devices</source>
        <translation>Dispositivos de salida virtuales</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="223"/>
        <source>&amp;Input Devices</source>
        <translation>&amp;Dispositivos de entrada</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="250"/>
        <source>&lt;i&gt;No input devices available&lt;/i&gt;</source>
        <translation>&lt;i&gt;No hay dispositivos de entrada disponibles&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="269"/>
        <source>All Input Devices</source>
        <translation>Todos los dispositivos de entrada</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="274"/>
        <source>All Except Monitors</source>
        <translation>Todos excepto los monitores</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="279"/>
        <source>Hardware Input Devices</source>
        <translation>Dispositivos de entrada por hardware</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="284"/>
        <source>Virtual Input Devices</source>
        <translation>Dispositivos de entrada virtuales</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="289"/>
        <source>Monitors</source>
        <translation>Monitores</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="298"/>
        <source>&amp;Configuration</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="325"/>
        <source>&lt;i&gt;No cards available for configuration&lt;/i&gt;</source>
        <translation>&lt;i&gt;No hay tarjetas disponibles para configurar&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="336"/>
        <source>Show volume meters</source>
        <translation>Mostrar los medidores de volumen</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="347"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="159"/>
        <source> (plugged in)</source>
        <translation> (conectado)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="163"/>
        <location filename="../../mainwindow.cc" line="257"/>
        <source> (unavailable)</source>
        <translation> (no disponible)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="165"/>
        <location filename="../../mainwindow.cc" line="254"/>
        <source> (unplugged)</source>
        <translation> (desconectado)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="386"/>
        <source>Failed to read data from stream</source>
        <translation>Fallo al leer datos del flujo</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="430"/>
        <source>Peak detect</source>
        <translation>Detección de picos</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="431"/>
        <source>Failed to create monitoring stream</source>
        <translation>Fallo al crear flujo de monitoreo</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="446"/>
        <source>Failed to connect monitoring stream</source>
        <translation>Fallo al conectarse al flujo de monitoreo</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="585"/>
        <source>Ignoring sink-input due to it being designated as an event and thus handled by the Event widget</source>
        <translation>Se ignora el &quot;sink&quot; por estar designado como un evento, siendo así manejado por la miniaplicación Eventos</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="757"/>
        <source>System Sounds</source>
        <translation>Sonidos del sistema</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="1088"/>
        <source>Establishing connection to PulseAudio. Please wait...</source>
        <translation>Estableciendo la conexión a PulseAudio. Espere...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../pavucontrol.cc" line="67"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="88"/>
        <source>Card callback failure</source>
        <translation>Fallo en la llamada de respuesta de la tarjeta</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="111"/>
        <source>Sink callback failure</source>
        <translation>Fallo en la llamada de respuesta al sumidero</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="134"/>
        <source>Source callback failure</source>
        <translation>Fallo en la llamada de respuesta a la fuente</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="153"/>
        <source>Sink input callback failure</source>
        <translation>Fallo en la llamada de respuesta de entrada sumidero</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="172"/>
        <source>Source output callback failure</source>
        <translation>Fallo en la llamada de respuesta de salida fuente</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="212"/>
        <source>Client callback failure</source>
        <translation>Fallo en la llamada de respuesta al cliente</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="228"/>
        <source>Server info callback failure</source>
        <translation>Fallo en la llamada de respuesta por información del servidor</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="246"/>
        <location filename="../../pavucontrol.cc" line="543"/>
        <source>Failed to initialize stream_restore extension: %s</source>
        <translation>Fallo al iniciar la extensión stream_restore: %s</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="264"/>
        <source>pa_ext_stream_restore_read() failed</source>
        <translation>pa_ext_stream_restore_read() ha fallado</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="282"/>
        <location filename="../../pavucontrol.cc" line="557"/>
        <source>Failed to initialize device restore extension: %s</source>
        <translation>Error al inicializar la extensión de restauración del dispositivo: %s</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="303"/>
        <source>pa_ext_device_restore_read_sink_formats() failed</source>
        <translation>pa_ext_device_restore_read_sink_formats() ha fallado</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="321"/>
        <location filename="../../pavucontrol.cc" line="570"/>
        <source>Failed to initialize device manager extension: %s</source>
        <translation>Error al inicializar la extensión de gestión del dispositivo: %s</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="340"/>
        <source>pa_ext_device_manager_read() failed</source>
        <translation>pa_ext_device_manager_read() ha fallado</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="357"/>
        <source>pa_context_get_sink_info_by_index() failed</source>
        <translation>pa_context_get_sink_info_by_index() ha fallado</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="370"/>
        <source>pa_context_get_source_info_by_index() failed</source>
        <translation>pa_context_get_source_info_by_index() ha fallado</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="383"/>
        <location filename="../../pavucontrol.cc" line="396"/>
        <source>pa_context_get_sink_input_info() failed</source>
        <translation>pa_context_get_sink_input_info() ha fallado</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="409"/>
        <source>pa_context_get_client_info() failed</source>
        <translation>pa_context_get_client_info() ha fallado</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="419"/>
        <location filename="../../pavucontrol.cc" line="484"/>
        <source>pa_context_get_server_info() failed</source>
        <translation>pa_context_get_server_info() ha fallado</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="432"/>
        <source>pa_context_get_card_info_by_index() failed</source>
        <translation>pa_context_get_card_info_by_index() ha fallado</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="475"/>
        <source>pa_context_subscribe() failed</source>
        <translation>pa_context_subscribe() ha fallado</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="491"/>
        <source>pa_context_client_info_list() failed</source>
        <translation>pa_context_client_info_list() ha fallado</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="498"/>
        <source>pa_context_get_card_info_list() failed</source>
        <translation>pa_context_get_card_info_list() ha fallado</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="505"/>
        <source>pa_context_get_sink_info_list() failed</source>
        <translation>pa_context_get_sink_info_list() ha fallado</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="512"/>
        <source>pa_context_get_source_info_list() failed</source>
        <translation>pa_context_get_source_info_list() ha fallado</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="519"/>
        <source>pa_context_get_sink_input_info_list() failed</source>
        <translation>pa_context_get_sink_input_info_list() ha fallado</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="526"/>
        <source>pa_context_get_source_output_info_list() failed</source>
        <translation>pa_context_get_source_output_info_list() ha fallado</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="585"/>
        <location filename="../../pavucontrol.cc" line="636"/>
        <source>Connection failed, attempting reconnect</source>
        <translation>La conexión ha fallado; intentando reconectar</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="608"/>
        <location filename="../../pavucontrol.cc" line="668"/>
        <source>PulseAudio Volume Control</source>
        <translation>Control de volumen de PulseAudio</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="623"/>
        <source>Connection to PulseAudio failed. Automatic retry in 5s

In this case this is likely because PULSE_SERVER in the Environment/X11 Root Window Properties
or default-server in client.conf is misconfigured.
This situation can also arrise when PulseAudio crashed and left stale details in the X11 Root Window.
If this is the case, then PulseAudio should autospawn again, or if this is not configured you should
run start-pulseaudio-x11 manually.</source>
        <translation>La conexión a PulseAudio ha fallado. Reintento automático en 5s

En este caso es probable porque PULSE_SERVER en las propiedades de Entorno/Ventana raíz de X11
o servidor por omisión en client.conf esté mal configurada.
Esta situación también puede surgir cuando PulseAudio ha fallado y dejado restos en la Ventana raíz de X11.
Si este es el caso, entonces PulseAudio debería reiniciarse de nuevo, o, si esto no está configurado, usted debería
ejecutar start-pulseaudio-x11 manualmente.</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="676"/>
        <source>Select a specific tab on load.</source>
        <translation>Seleccionar una pestaña específica al cargar.</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="679"/>
        <source>Retry forever if pa quits (every 5 seconds).</source>
        <translation>Reintentar indefinidamente si pa termina (cada 5 segundos).</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="682"/>
        <source>Maximize the window.</source>
        <translation>Maximizar la ventana.</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="707"/>
        <source>Fatal Error: Unable to connect to PulseAudio</source>
        <translation>Error fatal: no se puede reconectar con PulseAudio</translation>
    </message>
</context>
<context>
    <name>RoleWidget</name>
    <message>
        <location filename="../../rolewidget.cc" line="59"/>
        <source>pa_ext_stream_restore_write() failed</source>
        <translation>pa_ext_stream_restore_write() ha fallado</translation>
    </message>
</context>
<context>
    <name>SinkInputWidget</name>
    <message>
        <location filename="../../sinkinputwidget.cc" line="36"/>
        <source>on</source>
        <translation>encendido</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="39"/>
        <source>Terminate Playback</source>
        <translation>Terminar la reproducción</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="53"/>
        <source>Unknown output</source>
        <translation>Salida desconocida</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="64"/>
        <source>pa_context_set_sink_input_volume() failed</source>
        <translation>pa_context_set_sink_input_volume() ha fallado</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="79"/>
        <source>pa_context_set_sink_input_mute() failed</source>
        <translation>pa_context_set_sink_input_mute() ha fallado</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="89"/>
        <source>pa_context_kill_sink_input() failed</source>
        <translation>pa_context_kill_sink_input() ha fallado</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="114"/>
        <source>pa_context_move_sink_input_by_index() failed</source>
        <translation>pa_context_move_sink_input_by_index() ha fallado</translation>
    </message>
</context>
<context>
    <name>SinkWidget</name>
    <message>
        <location filename="../../sinkwidget.cc" line="81"/>
        <source>pa_context_set_sink_volume_by_index() failed</source>
        <translation>pa_context_set_sink_volume_by_index() ha fallado</translation>
    </message>
    <message>
        <source>Volume Control Feedback Sound</source>
        <translation type="vanished">Sonido de Retorno del Control de Volúmen</translation>
    </message>
    <message>
        <location filename="../../sinkwidget.cc" line="96"/>
        <source>pa_context_set_sink_mute_by_index() failed</source>
        <translation>pa_context_set_sink_mute_by_index() ha fallado</translation>
    </message>
    <message>
        <location filename="../../sinkwidget.cc" line="110"/>
        <source>pa_context_set_default_sink() failed</source>
        <translation>pa_context_set_default_sink() ha fallado</translation>
    </message>
    <message>
        <location filename="../../sinkwidget.cc" line="126"/>
        <source>pa_context_set_sink_port_by_index() failed</source>
        <translation>pa_context_set_sink_port_by_index() ha fallado</translation>
    </message>
    <message>
        <location filename="../../sinkwidget.cc" line="166"/>
        <source>pa_ext_device_restore_save_sink_formats() failed</source>
        <translation>pa_ext_device_restore_save_sink_formats() ha fallado</translation>
    </message>
</context>
<context>
    <name>SourceOutputWidget</name>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="36"/>
        <source>from</source>
        <translation>desde</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="39"/>
        <source>Terminate Recording</source>
        <translation>Terminar la grabación</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="60"/>
        <source>Unknown input</source>
        <translation>Entrada desconocida</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="72"/>
        <source>pa_context_set_source_output_volume() failed</source>
        <translation>pa_context_set_source_output_volume() ha fallado</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="87"/>
        <source>pa_context_set_source_output_mute() failed</source>
        <translation>pa_context_set_source_output_mute() ha fallado</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="98"/>
        <source>pa_context_kill_source_output() failed</source>
        <translation>pa_context_kill_source_output() ha fallado</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="125"/>
        <source>pa_context_move_source_output_by_index() failed</source>
        <translation>pa_context_move_source_output_by_index() ha fallado</translation>
    </message>
</context>
<context>
    <name>SourceWidget</name>
    <message>
        <location filename="../../sourcewidget.cc" line="35"/>
        <source>pa_context_set_source_volume_by_index() failed</source>
        <translation>pa_context_set_source_volume_by_index() ha fallado</translation>
    </message>
    <message>
        <location filename="../../sourcewidget.cc" line="50"/>
        <source>pa_context_set_source_mute_by_index() failed</source>
        <translation>pa_context_set_source_mute_by_index() ha fallado</translation>
    </message>
    <message>
        <location filename="../../sourcewidget.cc" line="64"/>
        <source>pa_context_set_default_source() failed</source>
        <translation>pa_context_set_default_source() ha fallado</translation>
    </message>
    <message>
        <location filename="../../sourcewidget.cc" line="80"/>
        <source>pa_context_set_source_port_by_index() failed</source>
        <translation>pa_context_set_source_port_by_index() ha fallado</translation>
    </message>
</context>
<context>
    <name>StreamWidget</name>
    <message>
        <location filename="../../streamwidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="32"/>
        <source>Device Title</source>
        <translation>Título del dispositivo</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="52"/>
        <source>direction</source>
        <translation>dirección</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="59"/>
        <source>device</source>
        <translation>dispositivo</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="66"/>
        <source>Mute audio</source>
        <translation>Silenciar el sonido</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="79"/>
        <source>Lock channels together</source>
        <translation>Bloquear juntos los canales</translation>
    </message>
    <message>
        <source>Device</source>
        <translation type="vanished">Dispositivo</translation>
    </message>
    <message>
        <location filename="../../streamwidget.cc" line="34"/>
        <source>Terminate</source>
        <translation>Terminar</translation>
    </message>
</context>
</TS>
